*******************************************************************************
*Decomposes total, predicted, and residual income inequality, for males 
*between the ages of 18 and 55, into inequality across municipalities and 
*inequality within municipalities, by country. 
*******************************************************************************

capture log close
clear
set mem 18000000
global thedir = "INSERT DIRECTORY FOR FINAL DATA OUTPUT HERE"
global aejfinalcode = "INSERT DIRECTORY CONTAINING DATA INPUTS HERE"
cd $aejfinalcode
log using aej_dcrescntry, replace

/*Data files used as inputs:
			ry`Y'.dta
			Y=BL, BR, CA, CI, CO, EC, ES, GT, HO, MX, PA, PE, PM, US, UY, VE
				 (These are the results of the Mincer decompositions, by country, with the 
				 FIPS country code used in the file naming convention. All are produced 
				 by aej_mincer.do)
Final data files produced (will be input into the Matlab file aej_inequality.m)
			ydecomp.txt
*/

/* ***---Note: You must download and install the Stata add-on module
	ineqdeco to run this file. Type ssc install ineqdeco from the Stata command
	line or see http://ideas.repec.org/c/boc/bocode/s366002.html
	
	Stephen P. Jenkins, 1999. "INEQDECO: Stata module to calculate inequality indices with 
	decomposition by subgroup,"  Statistical Software Components S366002, Boston College 
	Department of Economics, revised 26 May 2008.
*/

/* ***---Note: This file decomposes total, predicted, and residual income inequality 
		in the Americas, for males between the ages of 18 and 55, into
		inequality across municipalities and inequality within municipalities, by country. 
		The output of this file is used as input into the Matlab file inequality.m, 
		which further decomposes total inequality (at the overall Americas level) into 
		cross-country, cross-municipality, and within-municipality inequality. The output 
		file ydecomp.txt also contains the country-by-country decompositions that are 
		reported in Table 2.
*/

**************************************
***--Merge Data
**************************************

use ryBL, clear
append using ryBR
append using ryCA
append using ryCI
append using ryCO
append using ryEC
append using ryES
append using ryGT
append using ryHO
append using ryMX
append using ryPA
append using ryPE
append using ryPM
append using ryUS
append using ryUY
append using ryVE

keep admin1 admin2 admin3 cntry yepcip ww xb yres

replace admin2=0 if admin2==.
replace admin3=0 if admin3==.
encode cntry, g(ccnum)
tab ccnum

replace yepcip=exp(yepcip)
replace yres=exp(yres)
replace xb=exp(xb)
gen munic=100000*admin1+admin3
replace munic=10000*admin1+100*admin2 + admin3 if cntry=="PE"
save merged_residdata, replace


*Decomposition of inequality between municipalities 

foreach X of num 1/16 {
	 use merged_residdata, clear
	 keep if ccnum==`X'
	 gen id=`X'
   ineqdeco yepcip [aw=ww], bygroup(munic)
   gen geb0y=r(between_ge0)
   gen gew0y=r(within_ge0)
	 gen get0y=r(ge0)
	 gen geb1y=r(between_ge1)
   gen gew1y=r(within_ge1)
	 gen get1y=r(ge1)
	 gen p90p50y=r(p90p50)
	 gen p90p10y=r(p90p10)
	 ineqdeco xb [aw=ww], bygroup(munic)
   gen geb0xb=r(between_ge0)
   gen gew0xb=r(within_ge0)
	 gen get0xb=r(ge0)
	 gen geb1xb=r(between_ge1)
   gen gew1xb=r(within_ge1)
	 gen get1xb=r(ge1)
	 gen p90p50xb=r(p90p50)
	 gen p90p10xb=r(p90p10)
	 ineqdeco yres [aw=ww], bygroup(munic)
   gen geb0yres=r(between_ge0)
   gen gew0yres=r(within_ge0)
	 gen get0yres=r(ge0)
	 gen geb1yres=r(between_ge1)
   gen gew1yres=r(within_ge1)
	 gen get1yres=r(ge1)
	 gen p90p50yres=r(p90p50)
	 gen p90p10yres=r(p90p10)
	 replace yres=ln(yres)
	 replace xb=ln(xb)
   replace yepcip=ln(yepcip)
   summ yres [aw=ww]
	 gen se_yres=r(Var)
	 summ xb [aw=ww]
	 gen se_xb=r(Var)
	 summ yepcip [aw=ww]
	 gen se_yepcip=r(Var)
   replace yepcip=exp(yepcip)	 
	 summ yepcip [aw=ww]
	 gen mean_yepcip=r(mean) 
	 replace xb=exp(xb)	 
	 summ xb [aw=ww]
	 gen mean_xb=r(mean)
   replace yres=exp(yres)	 
	 summ yres [aw=ww]
	 gen mean_yres=r(mean)
	 collapse (mean) ge* se* p90* id mean*
	 saveold cntry_resdecomp`X', replace
}

use cntry_resdecomp1, clear
foreach X of num 2/16 {
	append using cntry_resdecomp`X'
}


*re-order so that municipality geo-referenced countires 
*and region geo-referenced countries grouped together
*(with municipality countries given lower numbers), for
*easy manipulation in matlab

gen cnum=.
replace cnum=	1	if id==	1
replace cnum=	2	if id==	2
replace cnum=	12	if id==	3
replace cnum=	13	if id==	4
replace cnum=	14	if id==	5
replace cnum=	15	if id==	6
replace cnum=	3	if id==	7
replace cnum=	4	if id==	8
replace cnum=	5	if id==	9
replace cnum=	6	if id==	10
replace cnum=	8	if id==	11
replace cnum=	9	if id==	12
replace cnum=	7	if id==	13
replace cnum=	10	if id==	14
replace cnum=	16	if id==	15
replace cnum=	11	if id==	16
sort cnum
drop id
saveold $thedir/aej_cntry_resdecomp, replace

*add country populations that will need for weighting in the 
*decompositions in matlab (taken from the 2000 Penn World Tables)

gen nj=.
replace nj=	8.15262	if cnum==	1
replace nj=	175.552771	if cnum==	2
replace nj=	6.122515	if cnum==	3
replace nj=	12.820296	if cnum==	4
replace nj=	6.200898	if cnum==	5
replace nj=	100.0879	if cnum==	6
replace nj=	2.836298	if cnum==	7
replace nj=	5.585828	if cnum==	8
replace nj=	27.012899	if cnum==	9
replace nj=	284.1537	if cnum==	10
replace nj=	23.542649	if cnum==	11
replace nj=	30.68904	if cnum==	12
replace nj=	15.153797	if cnum==	13
replace nj=	39.685655	if cnum==	14
replace nj=	12.920092	if cnum==	15
replace nj=	3.334074	if cnum==	16

gen nj_eq=1 /*for equal population weights*/

outsheet cnum	mean_yepcip	get0y	geb0y	gew0y	get0xb geb0xb	gew0xb	get0yres	/*
*/ geb0yres gew0yres	get1y	geb1y gew1y	get1xb	geb1xb	gew1xb	/*
*/ get1yres	geb1yres	gew1yres	nj	nj_eq mean_yres mean_xb /*
*/ using $thedir/ydecomp.txt, nonames noquote nolabel replace







